@@ -1,16 +1,15 @@
 from __future__ import annotations
 
-from collections import OrderedDict
-from itertools import cycle, count
 import logging
-from multiprocessing import Process, Queue, SimpleQueue
 import queue
 import random
-from threading import Thread
 import time
 import traceback as tb
-from typing import Any, Callable, Dict, Iterable, Optional
-
+from collections import OrderedDict
+from itertools import count, cycle
+from multiprocessing import Process, Queue, SimpleQueue
+from threading import Thread
+from typing import Any, Callable, Dict, Generator, Iterable, Optional
 
 from ..utils import make_partial
 
@@ -58,8 +57,13 @@ class PrefetchUnit(Process):
             else:
                 try:
                     item = item if self.processing_func is None else self.processing_func(item)
-                    self.queue.put((item, self.gid, idx, False))
-                    idx += 1
+                    if isinstance(item, Generator):
+                        for _item in item:
+                            self.queue.put((item, self.gid, idx, False))
+                            idx += 1
+                    else:
+                        self.queue.put((item, self.gid, idx, False))
+                        idx += 1
                 except Exception as e:
                     if self.ignore_error:
                         self.queue.put((tb.format_exc(), self.gid, idx, True))
